==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/AzureFileFilterDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Filter details to transfer Azure files
 * @property filePathList List of full path of the files to be transferred.
 * @property filePrefixList Prefix list of the Azure files to be transferred.
 * @property fileShareList List of file shares to be transferred.
 */
public data class AzureFileFilterDetailsArgs(
    public val filePathList: Output<List<String>>? = null,
    public val filePrefixList: Output<List<String>>? = null,
    public val fileShareList: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs =
        com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs.builder()
            .filePathList(filePathList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .filePrefixList(filePrefixList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .fileShareList(fileShareList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AzureFileFilterDetailsArgs].
 */
@PulumiTagMarker
public class AzureFileFilterDetailsArgsBuilder internal constructor() {
    private var filePathList: Output<List<String>>? = null

    private var filePrefixList: Output<List<String>>? = null

    private var fileShareList: Output<List<String>>? = null

    /**
     * @param value List of full path of the files to be transferred.
     */
    @JvmName("kfxkwncnvildgtvy")
    public suspend fun filePathList(`value`: Output<List<String>>) {
        this.filePathList = value
    }

    @JvmName("oepyscllwdrmlhsx")
    public suspend fun filePathList(vararg values: Output<String>) {
        this.filePathList = Output.all(values.asList())
    }

    /**
     * @param values List of full path of the files to be transferred.
     */
    @JvmName("ysgogtyftsrodyxr")
    public suspend fun filePathList(values: List<Output<String>>) {
        this.filePathList = Output.all(values)
    }

    /**
     * @param value Prefix list of the Azure files to be transferred.
     */
    @JvmName("nptaqjdaddjkepga")
    public suspend fun filePrefixList(`value`: Output<List<String>>) {
        this.filePrefixList = value
    }

    @JvmName("urrvsmgptudajoqs")
    public suspend fun filePrefixList(vararg values: Output<String>) {
        this.filePrefixList = Output.all(values.asList())
    }

    /**
     * @param values Prefix list of the Azure files to be transferred.
     */
    @JvmName("cscrnwjibcqopumq")
    public suspend fun filePrefixList(values: List<Output<String>>) {
        this.filePrefixList = Output.all(values)
    }

    /**
     * @param value List of file shares to be transferred.
     */
    @JvmName("qtvkwdeyvmhjyyyh")
    public suspend fun fileShareList(`value`: Output<List<String>>) {
        this.fileShareList = value
    }

    @JvmName("wxdkppsrgximwcus")
    public suspend fun fileShareList(vararg values: Output<String>) {
        this.fileShareList = Output.all(values.asList())
    }

    /**
     * @param values List of file shares to be transferred.
     */
    @JvmName("cntraxqbigqgnevi")
    public suspend fun fileShareList(values: List<Output<String>>) {
        this.fileShareList = Output.all(values)
    }

    /**
     * @param value List of full path of the files to be transferred.
     */
    @JvmName("xskwnkosinydeyqf")
    public suspend fun filePathList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePathList = mapped
    }

    /**
     * @param values List of full path of the files to be transferred.
     */
    @JvmName("jyhdhsyaxwbdrnga")
    public suspend fun filePathList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filePathList = mapped
    }

    /**
     * @param value Prefix list of the Azure files to be transferred.
     */
    @JvmName("naaduejcrbqhrejl")
    public suspend fun filePrefixList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePrefixList = mapped
    }

    /**
     * @param values Prefix list of the Azure files to be transferred.
     */
    @JvmName("dlahwhljtkyxqgsl")
    public suspend fun filePrefixList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filePrefixList = mapped
    }

    /**
     * @param value List of file shares to be transferred.
     */
    @JvmName("xivcveyqtpbtlgqs")
    public suspend fun fileShareList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileShareList = mapped
    }

    /**
     * @param values List of file shares to be transferred.
     */
    @JvmName("qilxxebwolexoskv")
    public suspend fun fileShareList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fileShareList = mapped
    }

    internal fun build(): AzureFileFilterDetailsArgs = AzureFileFilterDetailsArgs(
        filePathList = filePathList,
        filePrefixList = filePrefixList,
        fileShareList = fileShareList,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databox/kotlin/inputs/AzureFileFilterDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databox.kotlin.inputs

import com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Filter details to transfer Azure files
 * @property filePathList List of full path of the files to be transferred.
 * @property filePrefixList Prefix list of the Azure files to be transferred.
 * @property fileShareList List of file shares to be transferred.
 */
public data class AzureFileFilterDetailsArgs(
    public val filePathList: Output<List<String>>? = null,
    public val filePrefixList: Output<List<String>>? = null,
    public val fileShareList: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs =
        com.pulumi.azurenative.databox.inputs.AzureFileFilterDetailsArgs.builder()
            .filePathList(filePathList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .filePrefixList(filePrefixList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .fileShareList(fileShareList?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [AzureFileFilterDetailsArgs].
 */
@PulumiTagMarker
public class AzureFileFilterDetailsArgsBuilder internal constructor() {
    private var filePathList: Output<List<String>>? = null

    private var filePrefixList: Output<List<String>>? = null

    private var fileShareList: Output<List<String>>? = null

    /**
     * @param value List of full path of the files to be transferred.
     */
    @JvmName("vuedavpqrgnabmcm")
    public suspend fun filePathList(`value`: Output<List<String>>) {
        this.filePathList = value
    }

    @JvmName("nurswdibraskmkbc")
    public suspend fun filePathList(vararg values: Output<String>) {
        this.filePathList = Output.all(values.asList())
    }

    /**
     * @param values List of full path of the files to be transferred.
     */
    @JvmName("kjeljqiylvshveau")
    public suspend fun filePathList(values: List<Output<String>>) {
        this.filePathList = Output.all(values)
    }

    /**
     * @param value Prefix list of the Azure files to be transferred.
     */
    @JvmName("jimsufugnyssktao")
    public suspend fun filePrefixList(`value`: Output<List<String>>) {
        this.filePrefixList = value
    }

    @JvmName("kgdvglbdyoqwkenq")
    public suspend fun filePrefixList(vararg values: Output<String>) {
        this.filePrefixList = Output.all(values.asList())
    }

    /**
     * @param values Prefix list of the Azure files to be transferred.
     */
    @JvmName("kjevcadsthlfphss")
    public suspend fun filePrefixList(values: List<Output<String>>) {
        this.filePrefixList = Output.all(values)
    }

    /**
     * @param value List of file shares to be transferred.
     */
    @JvmName("uqfacuxskedldtvs")
    public suspend fun fileShareList(`value`: Output<List<String>>) {
        this.fileShareList = value
    }

    @JvmName("idpoajsudkjxkddt")
    public suspend fun fileShareList(vararg values: Output<String>) {
        this.fileShareList = Output.all(values.asList())
    }

    /**
     * @param values List of file shares to be transferred.
     */
    @JvmName("kkvewqywtnfrljyc")
    public suspend fun fileShareList(values: List<Output<String>>) {
        this.fileShareList = Output.all(values)
    }

    /**
     * @param value List of full path of the files to be transferred.
     */
    @JvmName("leterqrstfukiumu")
    public suspend fun filePathList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePathList = mapped
    }

    /**
     * @param values List of full path of the files to be transferred.
     */
    @JvmName("klydkrfrlaykaaco")
    public suspend fun filePathList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filePathList = mapped
    }

    /**
     * @param value Prefix list of the Azure files to be transferred.
     */
    @JvmName("dfyydvfsvhogpgyi")
    public suspend fun filePrefixList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.filePrefixList = mapped
    }

    /**
     * @param values Prefix list of the Azure files to be transferred.
     */
    @JvmName("iwmfvqmannuknonh")
    public suspend fun filePrefixList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.filePrefixList = mapped
    }

    /**
     * @param value List of file shares to be transferred.
     */
    @JvmName("nmpehnjunaeilkaw")
    public suspend fun fileShareList(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.fileShareList = mapped
    }

    /**
     * @param values List of file shares to be transferred.
     */
    @JvmName("fbvhtwmqbqnevchl")
    public suspend fun fileShareList(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.fileShareList = mapped
    }

    internal fun build(): AzureFileFilterDetailsArgs = AzureFileFilterDetailsArgs(
        filePathList = filePathList,
        filePrefixList = filePrefixList,
        fileShareList = fileShareList,
    )
}
